﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.IO;
using System.Windows.Forms;
using com.ptvag.xserver.xroute.wsclient;
using com.ptvag.xserver.common.wsclient;
using com.ptvag.jabba.clientbase.wsclient;
using System.Xml;
using System.Xml.Serialization;

namespace XRouteSnippet
{
    static class XRouteHelper
    {

        public static string ToSnippet(this Profile profile)
        {
            var ser = new XmlSerializer(typeof(Profile));
            var sb = new StringBuilder();
            var writer = new XmlTextWriter(new StringWriterWithEncoding(sb, Encoding.UTF8));
            ser.Serialize(writer, profile);
            return sb.ToString();
        }
    }

    class StringWriterWithEncoding : StringWriter
    {
        Encoding encoding;
        public StringWriterWithEncoding(StringBuilder builder, Encoding encoding)
            : base(builder)
        {
            this.encoding = encoding;
        }
        public override Encoding Encoding
        {
            get { return encoding; }
        }
    }

    
    
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }



        private void Form1_Load(object sender, EventArgs e)
        {
            Profile profile = new Profile()
            {
                Routing = new Routing()
                {
                    majorVersion = "2",
                    minorVersion = "0",
                    Vehicle = new RoutingVehicle()
                    {
                        Physical = new RoutingVehiclePhysical()
                        {
                            Dimension = new RoutingVehiclePhysicalDimension
                            {
                                height = 500
                            }
                        }
                    },
                    Course = new RoutingCourse()
                    {
                        AdditionalDataRules = new RoutingCourseAdditionalDataRules()
                        {
                            enabled = true,
                            layerName = "TruckAttributes",
                            VehicleSpecific = new RoutingCourseAdditionalDataRulesVehicleSpecific()
                            {
                                enabled = true
                            }
                        }
                    }
                }
            };
            
            
            
            CallerContextProperty ccpSnippet = new CallerContextProperty(){
                key = "ProfileXMLSnippet",
                value = XRouteHelper.ToSnippet(profile)
            };
            CallerContextProperty ccpPCoordFormat = new CallerContextProperty(){
                key = "CoordFormat",
                value = "PTV_MERCATOR"
            };
            CallerContext cc = new CallerContext(){
                properties = new CallerContextProperty[]{
                    ccpSnippet,
                    ccpPCoordFormat
                }
            };

            System.Windows.Forms.MessageBox.Show(ccpSnippet.value.Replace("<","\n<"));


            CWaypointDesc[] arrWaypointDesc = new CWaypointDesc[]{
                new CWaypointDesc(){
                    Coords = new CPoint[]{
                        new CPoint(){
                            Point = new CPlainPoint(){
                                X = 932461.0,
                                Y = 6266899.9
                            }
                        }
                    }
                },
                new CWaypointDesc(){
                    Coords = new CPoint[]{
                        new CPoint(){
                            Point = new CPlainPoint(){
                                X = 932121.0,
                                Y = 6265959.0
                            }
                        }
                    }
                }
            };

            
            CXRouteClient clientRoute = new CXRouteClient("","","http://127.0.0.1:50030/xroute/ws/XRoute")
            {
                CallerContext = cc
            };

            CRouteInfo routeInfo = clientRoute.CalculateRouteInfo(arrWaypointDesc, null, null);
        }
    }
}
